@@ -6,15 +6,6 @@ random = SystemRandom()
 
 KEY_CHARACTERS = string.letters + string.digits
 
-SIMPLE_KEYS = [
-    'username',
-    'first_name',
-    'last_name',
-    'email',
-    'is_staff',
-    'is_superuser',
-]
-
 def default_gen_secret_key(length=40):
     return ''.join([random.choice(KEY_CHARACTERS) for _ in range(length)])
 
